@@ -323,6 +323,33 @@ struct MediaInfo_Event_Global_BytesRead_0
     const MediaInfo_int8u*  Content;
 };
 
+/*-------------------------------------------------------------------------*/
+/* Decoded                                                                 */
+#define MediaInfo_Event_Global_Decoded 0xAF03
+
+struct MediaInfo_Event_Global_Decoded_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    size_t                  Content_Size;
+    const MediaInfo_int8u*  Content;
+    MediaInfo_int64u        Flags;
+};
+
+/*-------------------------------------------------------------------------*/
+/* AttachedFile                                                            */
+#define MediaInfo_Event_Global_AttachedFile 0xAF04
+
+struct MediaInfo_Event_Global_AttachedFile_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    size_t                  Content_Size;
+    const MediaInfo_int8u*  Content;
+    MediaInfo_int64u        Flags;
+    const char*             Name;
+    const char*             MimeType;
+    const char*             Description;
+};
+
 /*-------------------------------------------------------------------------*/
 /* MediaInfo_Event_Video_SliceInfo_0                                       */
 #define MediaInfo_Event_Video_SliceInfo 0x7801
@@ -424,7 +451,6 @@ struct MediaInfo_Event_General_SubFile_End_0
     MEDIAINFO_EVENT_GENERIC
 };
 
-
 /*-------------------------------------------------------------------------*/
 /* WaitForMoreData_Start                                                   */
 #define MediaInfo_Event_General_WaitForMoreData_Start 0x7008
@@ -480,7 +506,43 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
     MediaInfo_int16u        RecordedDateTime2;
     MediaInfo_int8u         Arb;
     MediaInfo_int8u         Verbosity;
-    char*                   Errors;
+    const char*             Errors;
+};
+struct MediaInfo_Event_DvDif_Analysis_Frame_1
+{
+    MEDIAINFO_EVENT_GENERIC
+    MediaInfo_int32u        TimeCode;
+    MediaInfo_int32u        RecordedDateTime1;
+    MediaInfo_int16u        RecordedDateTime2;
+    MediaInfo_int8u         Arb;
+    MediaInfo_int8u         Verbosity;
+    const char*             Errors;
+    size_t                  Video_STA_Errors_Count;
+    size_t*                 Video_STA_Errors;
+    size_t                  Audio_Data_Errors_Count;
+    size_t*                 Audio_Data_Errors;
+    MediaInfo_int32u        Captions_Errors; // bit 0 = parity issue
+};
+
+/*-------------------------------------------------------------------------*/
+/* Change in the stream config                                             */
+#define MediaInfo_Event_DvDif_Change 0xB002
+struct MediaInfo_Event_DvDif_Change_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    MediaInfo_int32u        Width;
+    MediaInfo_int32u        Height;
+    MediaInfo_int32u        VideoChromaSubsampling; // -1=unknown, 0=411, 1=420, 2=422
+    MediaInfo_int32u        VideoScanType; // -1=unknown
+    MediaInfo_int32u        VideoRatio_N;
+    MediaInfo_int32u        VideoRatio_D;
+    MediaInfo_int32u        VideoRate_N;
+    MediaInfo_int32u        VideoRate_D;
+    MediaInfo_int32u        AudioRate_N;
+    MediaInfo_int32u        AudioRate_D;
+    MediaInfo_int32u        AudioChannels;
+    MediaInfo_int32u        AudioBitDepth;
+    MediaInfo_int32u        Captions_Flags; // bit 0 = present
 };
 
 /***************************************************************************/
@@ -616,6 +678,12 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
 
 #define MediaInfo_Parser_Dxw            0x6B
 
+/***************************************************************************/
+/* MediaInfo XML                                                           */
+/***************************************************************************/
+
+#define MediaInfo_Parser_MiXml          0x6C
+
 /***************************************************************************/
 /* MPEG Video                                                              */
 /***************************************************************************/
